/**
 * Copyright (c) 2008 by The Shoe Shine Boy.
 * 
 * This file is part of JMS SMTP Bridge.
 * 
 * JMS SMTP Bridge is free software: you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or (at your 
 * option) any later version.
 *
 * JMS SMTP Bridge is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with JMS SMTP Bridge. If not, see <http://www.gnu.org/licenses/>.
 */
package com.gt.jmsmtpbridge.transform;

import java.rmi.RemoteException;
import java.util.Hashtable;

import javax.ejb.EJBException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.jms.Message;

/**
 * The Jms2SmtpTransformerBean Session Bean.
 * 
 * This is an abstract class. You should extend this bean and implement the transform() method 
 * in order to transform a JMS message into a hashtable that can be read by the SmtpSender Bean 
 * to send email(s).
 * 
 * Please check MapMsgTransformerBean and XmlMsgTransformerBean to see how to transform a JMS 
 * message into a hashtable and what all name/value pairs are needed to be loaded in the hashtable 
 * inorder for the hash to make sense for the SmtpSender Bean so that it can send mail(s).
 * 
 * @author The Shoe Shine Boy
 *
 */
@SuppressWarnings("serial")
public abstract class Jms2SmtpTransformerBean implements SessionBean {
	@Override
	public void ejbActivate() throws EJBException, RemoteException { }

	@Override
	public void ejbPassivate() throws EJBException, RemoteException { }

	@Override
	public void ejbRemove() throws EJBException, RemoteException { }

	@Override
	public void setSessionContext(SessionContext arg0) throws EJBException,
			RemoteException { }

	public void ejbCreate() { }
	
	/**
	 * This method must be implemented by the child class.
	 * 
	 * @param msg				The JMS Message
	 * @return					A hashtable that has all the relevant name/value pairs that 
	 * 							are needed by SmtpSender Bean to send mail(s)
	 * @throws RemoteException	Should be thrown in case of any fatal errors
	 */
	public abstract Hashtable<String, Object> transform(Message msg) throws RemoteException;
}
